==> qtjambi-network-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiNetwork/QSslServer_shell.h <==
#ifndef QSSLSERVER_SHELL_H
#define QSSLSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtnetwork-config.h>
#if QT_CONFIG(ssl)
#include <QtNetwork/qsslserver.h>
#endif //QT_CONFIG(ssl)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#if QT_CONFIG(ssl)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif //QT_CONFIG(ssl)
#include <QtNetwork/qsslsocket.h>
#include <QtNetwork/qtcpsocket.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(ssl)

class QSslServer_shell : public QSslServer, public QtJambiShellInterface
{
public:
    QSslServer_shell(QObject* parent0 = nullptr);
    ~QSslServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    void incomingConnection(qintptr socket0) override;
    QTcpSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSslServer_access : public QSslServer
{
    void __qt_incomingConnection_qintptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong socket0);
};

#endif // QT_CONFIG(ssl)
#endif // QSSLSERVER_SHELL_H

==> qtjambi-network-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiNetwork/QSslServer_shell.h <==
#ifndef QSSLSERVER_SHELL_H
#define QSSLSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtnetwork-config.h>
#if QT_CONFIG(ssl)
#include <QtNetwork/qsslserver.h>
#endif //QT_CONFIG(ssl)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qssl.h>
#if __has_include(<QtNetwork/qsslconfiguration.h>)
#include <QtNetwork/qsslconfiguration.h>
#endif
#if __has_include(<QtNetwork/qsslerror.h>)
#include <QtNetwork/qsslerror.h>
#endif
#if QT_CONFIG(ssl)
#if __has_include(<QtNetwork/qsslpresharedkeyauthenticator.h>)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif
#endif //QT_CONFIG(ssl)
#if __has_include(<QtNetwork/qsslsocket.h>)
#include <QtNetwork/qsslsocket.h>
#endif
#include <QtNetwork/qtcpsocket.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(ssl)

class QSslServer_shell : public QSslServer, public QtJambiShellInterface
{
public:
    QSslServer_shell(QObject* parent0 = nullptr);
    ~QSslServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    void incomingConnection(qintptr socket0) override;
    QTcpSocket* nextPendingConnection() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSslServer_access : public QSslServer
{
    void __qt_incomingConnection_qintptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong socket0);
};

#endif // QT_CONFIG(ssl)
#endif // QSSLSERVER_SHELL_H
